##
##  openpkg-import.spec -- OpenPKG RPM Package Specification
##  Copyright (c) 2000-2007 OpenPKG Foundation e.V. <http://openpkg.net/>
##  Copyright (c) 2000-2007 Ralf S. Engelschall <http://engelschall.com/>
##
##  Permission to use, copy, modify, and distribute this software for
##  any purpose with or without fee is hereby granted, provided that
##  the above copyright notice and this permission notice appear in all
##  copies.
##
##  THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
##  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
##  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
##  IN NO EVENT SHALL THE AUTHORS AND COPYRIGHT HOLDERS AND THEIR
##  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
##  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
##  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
##  USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
##  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
##  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
##  OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
##  SUCH DAMAGE.
##

#   package information
Name:         openpkg-import
Summary:      OpenPKG Operating System Import
URL:          http://cvs.openpkg.org/rlog?f=openpkg-src/openpkg-import/openpkg-import.spec
Vendor:       The OpenPKG Project
Packager:     OpenPKG Foundation e.V.
Distribution: OpenPKG Community
Class:        PLUS
Group:        System
License:      GPL
Version:      0
Release:      20070606

#   package options
%option       with_binutils no
%option       with_gcc      no
%option       with_mta      no
%option       with_mta_path sendmail

#   build information
Prefix:       %{l_prefix}
BuildRoot:    %{l_buildroot}
BuildPreReq:  OpenPKG, openpkg >= 20040130
PreReq:       OpenPKG, openpkg >= 20040130
AutoReq:      no
AutoReqProv:  no
%if "%{with_binutils}" == "yes"
Provides:     binutils = 2.14-%{release}
%endif
%if "%{with_gcc}" == "yes"
Provides:     gcc = 4.0-%{release}
%endif
%if "%{with_mta}" == "yes"
Provides:     MTA
Conflicts:    exim, postfix, sendmail, ssmtp
%endif

%description
    openpkg-import makes selected Operating System functionality
    available inside a OpenPKG instance.

%track

%prep

%build

%install
    rm -rf $RPM_BUILD_ROOT

%if "%{with_binutils}" == "yes"
    #   with_binutils uses the system tool chain commands
    %{l_shtool} mkdir -f -p -m 755 \
        $RPM_BUILD_ROOT%{l_prefix}/bin
    for tool_name in addr2line ar as gprof ld nm objcopy objdump ranlib readelf size strings; do
        tool_path="`%{l_shtool} path -p/bin:/usr/bin:/sbin:/usr/sbin:/usr/ccs/bin $tool_name 2>/dev/null || true`"
        if [ ".$tool_path" != . ]; then
            ln -s $tool_path $RPM_BUILD_ROOT%{l_prefix}/bin/$tool_name
        fi
    done
%endif

%if "%{with_gcc}" == "yes"
    #   with_gcc uses the system compiler commands
    %{l_shtool} mkdir -f -p -m 755 \
        $RPM_BUILD_ROOT%{l_prefix}/bin
    for tool_name in gcc g++ c%{l_nil}c c++ cpp; do
        tool_path="`%{l_shtool} path -p/bin:/usr/bin:/sbin:/usr/sbin:/usr/ccs/bin $tool_name`"
        if [ ".$tool_path" != . ]; then
            ( echo "#!/bin/sh"
              echo "exec $tool_path \"\$@\""
            ) >$RPM_BUILD_ROOT%{l_prefix}/bin/$tool_name
            chmod a+x $RPM_BUILD_ROOT%{l_prefix}/bin/$tool_name
        fi
    done
%endif

%if "%{with_mta}" == "yes"
    #   with_mta tries with_mta_path when absolute or hunts for with_mta_path in well known places
    sendmail="%{with_mta_path}"
    set -x
    case "$sendmail" in
        /* ) break ;;
        *  ) sendmail=`%{l_shtool} path -p/bin:/usr/bin:/sbin:/usr/sbin:/usr/lib $sendmail || true` ;;
    esac
    set -x
    if [ ".$sendmail" = . ]; then
        echo "mta \"%{with_mta_path}\" requested but not found." |\
            %{l_rpmtool} msg -b -t error 1>&2
        exit 1
    fi
    if [ ! -x "$sendmail" ]; then
        echo "mta \"%{with_mta_path}\" requested but \"$sendmail\" not executable." |\
            %{l_rpmtool} msg -b -t error 1>&2
        exit 1
    fi
    %{l_shtool} mkdir -f -p -m 755 \
        $RPM_BUILD_ROOT%{l_prefix}/sbin
    ln -s $sendmail \
        $RPM_BUILD_ROOT%{l_prefix}/sbin/sendmail
%endif

    %{l_rpmtool} files -v -ofiles -r$RPM_BUILD_ROOT %{l_files_std}

%files -f files

%clean
    rm -rf $RPM_BUILD_ROOT

